@@ -62,6 +62,7 @@ class NoBannerConsole(aioconsole.AsynchronousConsole):
 class WizWalkerConsole(Monitor):
     intro = "WizWalkerCLI\n{tasknum} task{s} running. Use help (?) for commands.\n"
     prompt = "WW > "
+    instance_finders = {}
 
     def write(self, message: str):
         self._sout.write(message + "\n")
@@ -107,11 +108,11 @@ class WizWalkerConsole(Monitor):
             close_fut.result(timeout=15)
 
     def do_start(self):
-        """Attach and hook to all clients"""
+        """Attach and hook to all new clients"""
         walker = self.get_local("walker")
-        walker.get_new_clients()
-        self.write(f"Attached to {len(walker.clients)} clients")
-        for idx, client in enumerate(walker.clients):
+        clients = walker.get_new_clients()
+        self.write(f"Attached to {len(clients)} new clients")
+        for idx, client in enumerate(clients):
             self.run_coro(client.activate_hooks(), None)
             self.write(f"client-{idx}: hooked all")
 
@@ -152,12 +153,6 @@ class WizWalkerConsole(Monitor):
         for idx, client in enumerate(walker.clients):
             self.write(f"client-{idx}: {self.run_coro(client.body.position())}")
 
-    def do_cache(self):
-        """Cache data"""
-        walker = self.get_local("walker")
-        self.run_coro(walker.cache())
-        self.write("Cached data")
-
     def do_teleport(self, x: float, y: float, z: float = None, yaw: float = None):
         """Teleport to a location
 
@@ -217,8 +212,14 @@ class WizWalkerConsole(Monitor):
 
     def do_findinstances(self, class_name: str):
         """Find instances of a class"""
-        pm = Pymem("WizardGraphicalClient.exe")
-        finder = InstanceFinder(pm, class_name)
+        if self.instance_finders.get(class_name):
+            finder = self.instance_finders[class_name]
+
+        else:
+            pm = Pymem("WizardGraphicalClient.exe")
+            finder = InstanceFinder(pm, class_name)
+            self.instance_finders[class_name] = finder
+
         instances = self.run_coro(finder.get_instances(), None)
 
         self.write(str(instances))
