@@ -18,6 +18,9 @@ from wizwalker import ExceptionalTimeout
 from wizwalker.constants import Keycode, kernel32, user32, gdi32
 
 
+DEFAULT_INSTALL = "C:/ProgramData/KingsIsle Entertainment/Wizard101"
+
+
 async def async_sorted(iterable, /, *, key=None, reverse=False):
     """
     sorted but key function is awaited
@@ -214,6 +217,11 @@ def get_wiz_install() -> Path:
     if _OVERRIDE_PATH:
         return Path(_OVERRIDE_PATH).absolute()
 
+    default_install_path = Path(DEFAULT_INSTALL)
+
+    if default_install_path.exists():
+        return default_install_path
+
     try:
         with winreg.OpenKey(
             winreg.HKEY_CURRENT_USER,
@@ -416,6 +424,40 @@ async def maybe_wait_for_value_with_timeout(
         )
 
 
+async def maybe_wait_for_any_value_with_timeout(
+    coro,
+    sleep_time: float = 0.5,
+    *,
+    timeout: Optional[float] = None,
+    ignore_exceptions: bool = True,
+):
+    possible_exception = None
+
+    async def _inner():
+        nonlocal possible_exception
+
+        while True:
+            try:
+                res = await coro()
+                if res is not None:
+                    return res
+
+            except Exception as e:
+                if ignore_exceptions:
+                    possible_exception = e
+                    await asyncio.sleep(sleep_time)
+
+                else:
+                    raise e
+
+    try:
+        return await asyncio.wait_for(_inner(), timeout)
+    except asyncio.TimeoutError:
+        raise ExceptionalTimeout(
+            f"Timed out waiting for coro {coro.__name__}", possible_exception
+        )
+
+
 def get_cache_folder() -> Path:
     """
     Get the wizwalker cache folder
@@ -589,7 +631,9 @@ def get_windows_from_predicate(predicate: Callable) -> list:
         return 1
 
     enumwindows_func_type = ctypes.WINFUNCTYPE(
-        ctypes.c_bool, ctypes.c_int, ctypes.POINTER(ctypes.c_int),
+        ctypes.c_bool,
+        ctypes.c_int,
+        ctypes.POINTER(ctypes.c_int),
     )
 
     callback = enumwindows_func_type(callback)
